# eric7.EricCore.EricProcess

Module implementing a QProcess derived class with a timeout and convenience signals.

### Global Attributes

None

### Classes

EricProcess | Class implementing a QProcess derived class with a timeout and convenience signals succeeded and failed.

### Functions

None

## EricProcess

Class implementing a QProcess derived class with a timeout and convenience signals succeeded and failed.

### Signals

failed()
  emitted to indicate a process failure
succeeded()
  emitted to indicate that the process finished successfully
timeout()
  emitted to indicate the expiry of the configured timeout value

### Derived from

QProcess

### Class Attributes

None

### Class Methods

None

### Methods

EricProcess | Constructor
__finished | Private slot handling the end of the process.
__started | Private slot handling the process start.
__timeout | Private slot to handle the timer interval exoiration.
timedOut | Public method to test, if the process timed out.
timeoutInterval | Public method to get the process timeout interval.

### Static Methods

None

#### EricProcess (Constructor)

EricProcess(timeout=30000, parent=None)

Constructor

timeout (int (optional))
  timeout value in milliseconds. If the process does not finish within this interval, it is killed. (defaults to 30000)
parent (QObject (optional))
  reference to the parent object (defaults to None)

#### EricProcess.__finished

__finished(exitCode, exitStatus)

Private slot handling the end of the process.

exitCode (int)
  exit code of the process (0 = success)
exitStatus (QProcess.ExitStatus)
  exit status of the process

#### EricProcess.__started

__started()

Private slot handling the process start.

#### EricProcess.__timeout

__timeout()

Private slot to handle the timer interval exoiration.

#### EricProcess.timedOut

timedOut()

Public method to test, if the process timed out.

Return:
  flag indicating a timeout

Return Type:
  bool

#### EricProcess.timeoutInterval

timeoutInterval()

Public method to get the process timeout interval.

Return:
  process timeout interval in milliseconds

Return Type:
  int

Up